<?php

/*************** Post Tags ***************/
	class postTagsWidget extends WP_Widget{
		public function __construct(){
			parent::__construct(
				'postTagsWidget',
				'MagaNews Tags',
				array('description' => __('Lists tags of the current post / category or the whole site (only shows up when tags exist)'))
			);
		}
		
		public function form($instance){
			$title = isset($instance['title'])? $instance['title']:'Tags';
			$maxNum = isset($instance['max_num'])? $instance['max_num']:'45';
			$minFontSize = isset($instance['min_font_size'])? $instance['min_font_size']:'12';
			$maxFontSize = isset($instance['max_font_size'])? $instance['max_font_size']:'16';
			?>
			<p>
            <label for="<?php echo $this->get_field_id( 'title' ); ?>"><?php _e( 'Title:' ); ?></label> 
            <input class="widefat" id="<?php echo $this->get_field_id( 'title' ); ?>" name="<?php echo $this->get_field_name( 'title' ); ?>" type="text" value="<?php echo esc_attr( $title ); ?>" />
            <label for="<?php echo $this->get_field_id( 'max_num' ); ?>"><?php _e( 'Maximum number of tags to show:' ); ?></label> 
            <input class="widefat" id="<?php echo $this->get_field_id( 'max_num' ); ?>" name="<?php echo $this->get_field_name( 'max_num' ); ?>" type="text" value="<?php echo $maxNum; ?>" /><br/>
            <label for="<?php echo $this->get_field_id( 'min_font_size' ); ?>"><?php _e( 'Minimum font size:' ); ?></label> 
            <input class="widefat" id="<?php echo $this->get_field_id( 'min_font_size' ); ?>" name="<?php echo $this->get_field_name( 'min_font_size' ); ?>" type="text" value="<?php echo $minFontSize; ?>" /><br/>
            <label for="<?php echo $this->get_field_id( 'max_font_size' ); ?>"><?php _e( 'Maximum font size:' ); ?></label> 
            <input class="widefat" id="<?php echo $this->get_field_id( 'max_font_size' ); ?>" name="<?php echo $this->get_field_name( 'max_font_size' ); ?>" type="text" value="<?php echo $maxFontSize; ?>" /><br/>
            </p>
        <?php
		}
		
		public function update($newInstance, $oldInstance){
			$instance = array();
			$instance['title'] = strip_tags($newInstance['title']);
			$instance['max_num'] = max(1, intval($newInstance['max_num']));
			$instance['min_font_size'] = max(1, intval($newInstance['min_font_size']));
			$instance['max_font_size'] = max(1, intval($newInstance['max_font_size']));
			return $instance;
		}
		
		public function widget($args, $instance){
			extract( $args );
			$title = apply_filters( 'widget_title', $instance['title'] );
			$maxNum = max(1, intval($instance['max_num']));
			$minFontSize = max(1, intval($instance['min_font_size']));
			$maxFontSize = max(1, intval($instance['max_font_size']));
	
			$html = $before_widget;
			if ( ! empty( $title ) )
				$html .= $before_title . $title . $after_title;
				$count = 0;
				?>
                
			
				<?php
					$html .= '<ul class="postTags">';
					if (is_single()){
						if (have_posts()):
							while(have_posts()):
								the_post();
								$tags = get_the_tags();
								if (!$tags) continue;
								foreach ($tags as $t):
									$html .= '<li><a href="'.get_tag_link($t->term_id).'">'.$t->name.'</a></li>';
								$count++;
								endforeach;
							endwhile;
						endif;
						wp_reset_postdata();
					} elseif (is_category() || is_page_template('three-column-front-page.php')){
						$catId = intval(get_query_var('cat'));
						$childCats = get_categories('child_of='.$catId);
						$args = 'cat='.$catId;
						if ($childCats){
							foreach($childCats as $c){
								$args .= ','.$c->cat_ID;
							}
						}
						
						$args .= '&posts_per_page=-1';
						
						$tIds = array();
						$tNames = array();
						$tCounts = array();
						$minCount = 1e10;
						$maxCount = 0;
						$postsInCat  = new WP_Query( $args );
						if ($postsInCat->have_posts()):
							while($postsInCat->have_posts() && $count<$maxNum):
								$postsInCat->the_post();
								$tags = get_the_tags();
								if (!$tags) continue;
								foreach ($tags as $t):
									if (in_array($t->term_id,$tIds)) continue;
									$tIds[] = $t->term_id;
									$tNames[] = $t->name;
									$tCounts[] = $t->count;
									$minCount = $minCount<$t->count?$minCount:$t->count;
									$maxCount = $maxCount>$t->count?$maxCount:$t->count;
									$count++;
									if ($count>=$maxNum) break;
								endforeach;
							endwhile;
						endif;
						
						foreach ($tIds as $i => $tId){
							$fontSize = $minFontSize;
							if ($maxCount > $minCount){
								$fontSize = ($tCounts[$i] - $minCount) / ($maxCount - $minCount) * ($maxFontSize - $minFontSize) + $minFontSize;
							}
							$html .= '<li><a href="'.get_tag_link($tId).'" style="font-size: '.$fontSize.'px">'.$tNames[$i].'</a></li>';
						}
						
					}
					$html .= '</ul>';
				?>
                
        
            <?php
			$html .= $after_widget;
			if ($count>0){
				echo $html;
			}
		}
	}
	
	register_widget('postTagsWidget');

?>