<?php

/*************** recent articles ***************/
	class recentArticlesWidget extends WP_Widget{
		public function __construct(){
			parent::__construct(
				'recentArticlesWidget',
				'MagaNews Recent Articles',
				array('description' => __('Lists the latest posts as recent articles'))
			);
		}
		
		public function form($instance){
			global $wp_query;
			$title = isset($instance['title'])? $instance['title']:'Recent Articles';
			$postsPerPage = isset($instance['posts_per_page'])? $instance['posts_per_page']:5;
			$excludeSticky = isset($instance['exclude_sticky'])? (bool) $instance['exclude_sticky']:false;
			$isPaginated = isset($instance['is_paginated'])? (bool) $instance['is_paginated']:false;
			?>
			<p>
            <label for="<?php echo $this->get_field_id( 'title' ); ?>"><?php _e( 'Title:' ); ?></label> 
            <input class="widefat" id="<?php echo $this->get_field_id( 'title' ); ?>" name="<?php echo $this->get_field_name( 'title' ); ?>" type="text" value="<?php echo esc_attr( $title ); ?>" /><br/>
            <label for="<?php echo $this->get_field_id( 'posts_per_page' ); ?>"><?php _e( 'Posts per page:' ); ?></label> 
            <input class="widefat" id="<?php echo $this->get_field_id( 'posts_per_page' ); ?>" name="<?php echo $this->get_field_name( 'posts_per_page' ); ?>" type="text" value="<?php echo $postsPerPage; ?>" /><br/>
            <input class="checkbox" id="<?php echo $this->get_field_id( 'exclude_sticky' ); ?>" name="<?php echo $this->get_field_name( 'exclude_sticky' ); ?>" type="checkbox" value="1" <?php echo $excludeSticky?'checked':''; ?>/> <label for="<?php echo $this->get_field_id( 'exclude_sticky' ); ?>"><?php _e( 'Exclude sticky posts' ); ?></label><br/>
            <input class="checkbox" id="<?php echo $this->get_field_id( 'is_paginated' ); ?>" name="<?php echo $this->get_field_name( 'is_paginated' ); ?>" type="checkbox" value="1" <?php echo $isPaginated?'checked':''; ?>/> <label for="<?php echo $this->get_field_id( 'is_paginated' ); ?>"><?php _e( 'Show pagination' ); ?></label> 
            </p>
        <?php
		}
		
		public function update($newInstance, $oldInstance){
			$instance = array();
			$instance['title'] = strip_tags($newInstance['title']);
			$instance['posts_per_page'] = max(1, intval($newInstance['posts_per_page']));
			$instance['exclude_sticky'] = (bool)$newInstance['exclude_sticky'];
			$instance['is_paginated'] = (bool)$newInstance['is_paginated'];
			return $instance;
		}
		
		public function widget($args, $instance){
			extract( $args );
			$title = apply_filters( 'widget_title', $instance['title'] );
			$postsPerPage = max(1, intval($instance['posts_per_page']));
			$excludeSticky = (bool)$instance['exclude_sticky'];
			$isPaginated = (bool)$instance['is_paginated'];
			$queryVarPrefix = NULL;
			$urlSections = explode('/', $_SERVER['REQUEST_URI']);
			if ($urlSections){
				$urlEnd = array_slice($urlSections,-1);
				$urlEnd = $urlEnd[0];
				if ($urlEnd == ''){
					$queryVarPrefix = 'page/';
				} elseif (strpos($urlEnd, '?') === false){
					$queryVarPrefix = '?paged=';
				} else{
					$queryVarPrefix = '&paged=';
				}
			}
	
			echo $before_widget;
			if ( ! empty( $title ) )
				echo $before_title . $title . $after_title;
				?>
                
			 <ul class="recentArticles">
				<?php
					global $query_string;
					$currentPage = max(1, get_query_var('paged'));
					$args = array( 'post_type' => 'post', 'ignore_sticky_posts'=>1, 'posts_per_page' => $postsPerPage, 'post__not_in' => $excludeSticky?get_option('sticky_posts'):array(), 'paged' => $currentPage );
					if (!is_page_template('three-column-front-page.php')){
						$args = array_merge( wp_parse_args($query_string), $args );
					}
					query_posts($args);
					if (have_posts()): while(have_posts()):
					the_post();
                ?>
                <li><p class="date"><?php the_time('M j'); ?></p>
                <h3><a href="<?php the_permalink(); ?>"><?php the_title(); ?></a></h3>
                <p class="excerpt"><?php echo get_the_excerpt(); ?> <span class="author">by <a href="<?php echo get_author_posts_url( get_the_author_meta('ID') );?>"><?php the_author();?></a></span></p>
                </li>
                <?php endwhile; else:?>
                <li>(No recent articles found.)</li>
                <?php endif; ?>
			</ul>
            	<?php
					global $wp_query;
					$numPages = $wp_query->max_num_pages;  
					  
					if ($numPages > 1 && $isPaginated){  
					  echo '<div class="pagination">';  
					  echo paginate_links(array(  
						  'base' => get_pagenum_link(1) . '%_%',  
						  'format' => $queryVarPrefix.'%#%',  
						  'current' => $currentPage,  
						  'total' => $numPages,  
						)); 
					  echo $after_widget; 
					} 
					
					wp_reset_query();
				?>
        
            <?php
			echo '</div>';
		}
	}
	
	register_widget('recentArticlesWidget');

?>